aboutsummaryrefslogtreecommitdiff
path: root/lib/netdev-provider.h
diff options
context:
space:
mode:
authorBen Pfaff <blp@nicira.com>2011-03-25 13:04:47 -0700
committerBen Pfaff <blp@nicira.com>2011-03-31 16:42:01 -0700
commit19993ef3caac9964c2bef6e31fc8699c4f4b53c8 (patch)
tree8783075dd7d2fd786f9759fe2fb016e02fcf6800 /lib/netdev-provider.h
parentd0c23a1a57f5bd994d3af124673a218e21528dd3 (diff)
netdev: Use sset instead of svec in netdev interface.
Diffstat (limited to 'lib/netdev-provider.h')
-rw-r--r--lib/netdev-provider.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/netdev-provider.h b/lib/netdev-provider.h
index 1a916f76..c6ebd2a5 100644
--- a/lib/netdev-provider.h
+++ b/lib/netdev-provider.h
@@ -166,7 +166,7 @@ struct netdev_class {
*
* If this netdev class does not support enumeration, this may be a null
* pointer. */
- int (*enumerate)(struct svec *all_names);
+ int (*enumerate)(struct sset *all_names);
/* Attempts to receive a packet from 'netdev' into the 'size' bytes in
* 'buffer'. If successful, returns the number of bytes in the received
@@ -330,11 +330,11 @@ struct netdev_class {
* this function must not add "" to 'types'.
*
* The caller is responsible for initializing 'types' (e.g. with
* svec_init()) before calling this function. The caller takes ownership
* of the strings added to 'types'.
*
* May be NULL if 'netdev' does not support QoS at all. */
- int (*get_qos_types)(const struct netdev *netdev, struct svec *types);
+ int (*get_qos_types)(const struct netdev *netdev, struct sset *types);
/* Queries 'netdev' for its capabilities regarding the specified 'type' of
* QoS. On success, initializes 'caps' with the QoS capabilities.
@@ -330,11 +330,11 @@ struct netdev_class {
*
* The caller is responsible for initializing 'types' (e.g. with
- * svec_init()) before calling this function. The caller takes ownership
- * of the strings added to 'types'.
+ * sset_init()) before calling this function. The caller retains ownership
+ * of 'types'.
*
* May be NULL if 'netdev' does not support QoS at all. */